@@ -9,7 +9,7 @@ package Error::Base;
 use 5.008008;
 use strict;
 use warnings;
-use version 0.77; our $VERSION = qv('v0.1.1');
+use version; our $VERSION = qv('v0.1.3');
 
 # Core modules
 use overload                    # Overload Perl operations
@@ -56,7 +56,7 @@ sub _stringify {
         return join qq{\n}, @{ $self->{-lines} }, q{};
     }
     else {
-        return 'Error::Base internal error: failed to stringify $self';
+        return 'Error::Base internal error: stringifing unthrown object';
     };
         
 }; ## _stringify
@@ -149,7 +149,7 @@ sub _trace {
         
         # Safety exit from while loop.
         $i++;
-        die 'Error::Base internal error: excessive backtrace: ', $!
+        die 'Error::Base internal error: excessive backtrace'
             if $i > 99;
 #~ last if $i > 9;                                             # DEBUG ONLY #~
         
@@ -489,11 +489,16 @@ package Error::Base::Late;   # switch package to avoid pseudo-global lexicals
 #       I chose heredocs and three long, arbitrary strings. 
 # 
 sub _late {
+    use strict;
+    use warnings;
     no warnings 'uninitialized';          # too many to count
-    
+#~ ##### CASE:
+#~ ##### @_    
     # No lexical variables loose in the outer block of the subroutine.
-    $Error::Base::Late::self    = shift 
-        or die 'Error::Base internal error: no $self: ', $!;
+    $Error::Base::Late::self    = shift;
+    if ( not ref $Error::Base::Late::self ) {
+        die 'Error::Base internal error: no $self';
+    };
     $Error::Base::Late::in      = shift || undef;
     return $Error::Base::Late::in 
         unless $Error::Base::Late::in =~ /[\$\@%]/; # no sigil, don't bother
@@ -557,11 +562,11 @@ sub _late {
                 $sigil      = q{%};
             } 
             else {
-                die 'Error::Base internal error: bad reftype: ', $!;
+                die 'Error::Base internal error: bad reftype';
             };
             
             #        my $key = $sigil?$Error::Base::Late::self->{'$key'}?;
-            push @code, 
+            push @Error::Base::Late::code, 
                 ( join q{}, 
                     $ch1, $key, $ch2, 
                     $sigil, $lbc, $ch3, $key, $ch4, $rbc, $ch5,
@@ -571,7 +576,7 @@ sub _late {
     # ... done unpacking.
     
     # Do the late interpolation phase. 
-    push @code, 
+    push @Error::Base::Late::code, 
         q**,
         q*<<Heredoc01_Y0uMaYFiReWHeNReaDYGRiDLeY;*,
 <<Heredoc02_Y0uMaYFiReWHeNReaDYGRiDLeY,
@@ -595,7 +600,10 @@ $Error::Base::Late::out     = eval
 $Error::Base::Late::eval_code
 Heredoc03_Y0uMaYFiReWHeNReaDYGRiDLeY
         
-        warn "Error::Base internal warning: in _late eval: $@" if $@;
+        if ($@) {
+            warn "Error::Base internal warning: in _late eval: $@";
+            return $Error::Base::Late::in;           # best we can do
+        };
         
 #~         ##### CASE
 #~         ##### $Error::Base::Late::self
@@ -610,6 +618,8 @@ Heredoc03_Y0uMaYFiReWHeNReaDYGRiDLeY
     # Heredocs add spurious newlines.
     chomp  $Error::Base::Late::out;
     chomp  $Error::Base::Late::out;
+#~ my $out =  $Error::Base::Late::out;
+#~ ##### $out;
     return $Error::Base::Late::out;
 }; ## _late
 
@@ -626,7 +636,7 @@ Error::Base - Simple structured errors with full backtrace
 
 =head1 VERSION
 
-This document describes Error::Base version v0.1.1
+This document describes Error::Base version v0.1.3
 
 =head1 SYNOPSIS
 
@@ -688,14 +698,17 @@ modules (and few of those), exports no symbols, and is purely object-oriented.
 I hope you will be able to use it commonly instead of a simple C<die()>. 
 You are not required to subclass it. 
 
+See the L<Error::Base::Cookbook|Error::Base::Cookbook> for examples. 
+
 =head1 METHODS 
 
 =head2 new()
 
     my $err     = Error::Base->new;             # constructor
     my $err     = Error::Base->new(
-                        'bartender:',           # lone string first okay
+                        'bartender',            # lone string first okay
                     -base       => 'Bar error:',
+                    -type       => 'last call',
                     -quiet      => 1,
                     -top        => 3,
                     -prepend    => '@! Black Tie Lunch:',
@@ -870,7 +883,7 @@ dense dump. So in future releases, the default may be changed to form
 C<< -prepend >> in some way for you if not defined. If you are certain you 
 want no prepending or indentation, pass the empty string, C<q{}>.
 
-=head2 LATE INTERPOLATION
+=head1 LATE INTERPOLATION
 
 It is possible to interpolate a variable that is I<not in scope> 
 into error message text. This is triggered by passing the value against a 
@@ -930,6 +943,8 @@ do so, successfully or not, please be so kind as to notify.
 
 =head1 SEE ALSO
 
+L<Error::Base::Cookbook|Error::Base::Cookbook>
+
 Many error-related modules are available on CPAN. Some do bizarre things. 
 
 L<Exception::Class|Exception::Class>, L<Error|Error>, L<Exception|Exception>, L<Carp|Carp>, L<Test::Trap|Test::Trap>.
@@ -944,21 +959,42 @@ This module emits error messages I<for> you; it is hoped you won't encounter
 any from within itself. If you do see one of these errors, kindly report to RT 
 so maintainer can take action. Thank you for helping. 
 
+All errors internal to this module are prefixed C<< Error::Base internal... >>
+
 =over
 
-=item C<< Error::Base internal error: excessive backtrace: >>
+=item C<< excessive backtrace >>
 
 Attempted to capture too many frames of backtrace. 
 You probably mis-set C<< -top >>, rational values of which are perhaps C<0..9>.
 
-=item C<< Error::Base internal error: unpaired args: >>
+=item C<< unpaired args: >>
 
 You do I<not> have to pass paired arguments to most public methods. 
 Perhaps you passed an odd number of args to a private method. 
 
-=item C<< Error::Base internal error: bad reftype: >>
+=item C<< bad reftype >>
 
-You attempted to late-interpolate a reference other than to a scalar, array, or hash. Don't pass such references as values to any key with the wrong sigil. 
+You attempted to late-interpolate a reference other than to a scalar, array, 
+or hash. Don't pass such references as values to any key with the wrong sigil. 
+
+=item C<< no $self >>
+
+Called a method without class or object. Did you call as function?
+
+=item C<< stringifing unthrown object >>
+
+An object of this class will stringify to its printable error message 
+(including backtrace if any) when thrown. There is nothing to see (yet) if 
+you try to print an object that has been constructed but not (yet) thrown. 
+This error is not fatal; it is returned as the stringification. 
+
+=item C<< in _late eval: >>
+
+Attempted to late-interpolate badly. Check your code. The interpolation 
+failed so you cannot expect to see the correct error message text. 
+On the offchance that you would like to see the stack backtrace anyway, 
+this error is not fatal. 
 
 =back
 
