@@ -3,7 +3,7 @@ package Error::Base::Cookbook;
 use 5.008008;
 use strict;
 use warnings;
-use version 0.77; our $VERSION = qv('v0.1.1');
+use version; our $VERSION = qv('v0.1.3');
 
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #                                                                           #
@@ -39,7 +39,7 @@ Error::Base::Cookbook - Examples of Error::Base usage
 
 =head1 VERSION
 
-This document describes Error::Base version v0.1.1
+This document describes Error::Base version v0.1.3
 
 =head1 DESCRIPTION
 
@@ -118,7 +118,7 @@ No need to plan ahead; just drop in a sanity check.
 In constructs like this, it's tempting to think you've covered every possible 
 case. Avoid this fallacy by checking explicitly for each implemented case. 
 
-    Error::Base->crash;         # emits 'Unimplemented error' with backtrace.
+    Error::Base->crash;         # emits 'Undefined error.' with backtrace.
     
 Don't forget to pass some error message text. Unless you're in real big foo.
 
@@ -252,7 +252,7 @@ parameters as L<new()|Error::Base/new()>.
         -code   => sub{
 #
     my $err = Error::Base->new('See me');
-    $err->cuss('Feel me');
+    $err->cuss('Feel me');                      # trace stored in object
 #
             },
         -lby    => 'return-scalar',
@@ -289,7 +289,7 @@ parameters as L<new()|Error::Base/new()>.
     $err->crank;                                # as object method
     
     my $err = Error::Base->new('See me');
-    $err->cuss('Feel me');
+    $err->cuss('Feel me');                      # trace stored in object
     
     my $err = Error::Base->cuss('x%@#*!');      # also a constructor
 
@@ -781,7 +781,7 @@ to expand and trace without throwing, invoke L<cuss()|Error::Base/cuss()>.
 Nothing special here; as usual, double quotes interpolate a variable that is 
 in scope at the place where the error is thrown. 
 
-=head1 Late Interpolation
+=head2 Late Interpolation
 
 =cut
 
@@ -856,11 +856,11 @@ and I<before> any prepending, indentation, line-breaking, or stack tracing.
         -code   => sub{
 #
     my $err     = Error::Base->new(
-                    '$scalar'       => 'scalar',
+                    '$sca'          => 'one',
                     '@ary_ref'      => [ 'white', 'black' ],
                     '%hash_ref'     => { hash => 'hog', toe => 'jam' },
                 );
-    $err->crash( '|$scalar|@ary_ref|$ary_ref[1]|@hash_ref{ hash, toe }|' );
+    $err->crash( '|$sca|@ary_ref|$ary_ref[1]|@hash_ref{ qw/ hash toe / }|' );
                                 # emits '|one|white black|black|hog jam|'
 #
             },
@@ -872,11 +872,11 @@ and I<before> any prepending, indentation, line-breaking, or stack tracing.
 =pod
 
     my $err     = Error::Base->new(
-                    '$scalar'       => 'one',
+                    '$sca'          => 'one',
                     '@ary_ref'      => [ 'white', 'black' ],
                     '%hash_ref'     => { hash => 'hog', toe => 'jam' },
                 );
-    $err->crash( '|$scalar|@ary_ref|$ary_ref[1]|@hash_ref{ hash, toe }|' );
+    $err->crash( '|$sca|@ary_ref|$ary_ref[1]|@hash_ref{ qw/ hash toe / }|' );
                                 # emits '|one|white black|black|hog jam|'
 
 You may use scalar or array placeholders, signifying them with the usual 
@@ -978,7 +978,27 @@ Perl uses the value of C<$"> (C<$LIST_SEPARATOR>).
 If, for some reason, you wish to see message parts and interpolated elements 
 joined by something else, localize C<$">. 
 
-=head1 Demo
+=head1 EXAMPLE CODE
+
+=head2 get_test_data
+
+=head2 words
+
+=head2 cook_dinner
+
+=head2 serve_chili
+
+=head2 add_recipie
+
+=head2 _crash
+
+=head2 bar
+
+This module contains executable code matching each snippet you see in POD; 
+this code is exercised by the Error::Base test suite. You're welcome to look. 
+Please, don't try to C<use> the ::Cookbook!
+
+=head1 DEMO
 
 Included in this distribution is a script, C<error-base-demo.pl>; output here. 
 You see a warning and a fatal error, each with stack backtrace from the 
